.. Copyright (C) 2014 Nick Janetakis <nick.janetakis@gmail.com>
.. Copyright (C) 2014-2017 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2014-2017 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.java`` Ansible role installs the default Java OpenJRE headless
packages for current OS release. It can also be used to install other Java or
OpenJDK/OpenJRE versions.
